@@ -287,10 +287,17 @@ nautilus_bookmark_connect_file (NautilusBookmark *bookmark)
         g_debug ("%s: creating file", nautilus_bookmark_get_name (bookmark));
 
         bookmark->file = nautilus_file_get (bookmark->location);
-        g_assert (!nautilus_file_is_gone (bookmark->file));
 
-        g_signal_connect_object (bookmark->file, "changed",
-                                 G_CALLBACK (bookmark_file_changed_callback), bookmark, 0);
+        if (nautilus_file_is_gone (bookmark->file))
+        {
+            g_warning ("%s: file is gone, skipping signal connection",
+                       nautilus_bookmark_get_name (bookmark));
+        }
+        else
+        {
+            g_signal_connect_object (bookmark->file, "changed",
+                                     G_CALLBACK (bookmark_file_changed_callback), bookmark, 0);
+        }
     }
 
     if (bookmark->icon == NULL ||
